@@ -57,6 +57,8 @@ enum {
 	NFTNL_EXPR_NG_MODULUS,
 	NFTNL_EXPR_NG_TYPE,
 	NFTNL_EXPR_NG_OFFSET,
+	NFTNL_EXPR_NG_SET_NAME,
+	NFTNL_EXPR_NG_SET_ID,
 };
 
 enum {
@@ -70,6 +72,11 @@ enum {
 	NFTNL_EXPR_RT_DREG,
 };
 
+enum {
+	NFTNL_EXPR_SOCKET_KEY	= NFTNL_EXPR_BASE,
+	NFTNL_EXPR_SOCKET_DREG,
+};
+
 enum {
 	NFTNL_EXPR_CMP_SREG	= NFTNL_EXPR_BASE,
 	NFTNL_EXPR_CMP_OP,
@@ -95,6 +102,11 @@ enum {
 	NFTNL_EXPR_CTR_BYTES,
 };
 
+enum {
+	NFTNL_EXPR_CONNLIMIT_COUNT = NFTNL_EXPR_BASE,
+	NFTNL_EXPR_CONNLIMIT_FLAGS,
+};
+
 enum {
 	NFTNL_EXPR_BITWISE_SREG	= NFTNL_EXPR_BASE,
 	NFTNL_EXPR_BITWISE_DREG,
@@ -226,6 +238,8 @@ enum {
 
 enum {
 	NFTNL_EXPR_FWD_SREG_DEV = NFTNL_EXPR_BASE,
+	NFTNL_EXPR_FWD_SREG_ADDR,
+	NFTNL_EXPR_FWD_NFPROTO,
 };
 
 enum {
@@ -236,6 +250,8 @@ enum {
 	NFTNL_EXPR_HASH_SEED,
 	NFTNL_EXPR_HASH_OFFSET,
 	NFTNL_EXPR_HASH_TYPE,
+	NFTNL_EXPR_HASH_SET_NAME,
+	NFTNL_EXPR_HASH_SET_ID,
 };
 
 enum {
